@@ -25,7 +25,6 @@
 #include <qtest_akonadi.h>
 
 #include <item.h>
-#include <collection.h>
 #include <itemfetchjob.h>
 #include <itemcreatejob.h>
 #include <itemfetchscope.h>
@@ -74,7 +73,7 @@ class IncidenceChangerTest : public QObject
     Collection mCollection;
 
     QHash<int, IncidenceChanger::ResultCode> mExpectedResultByChangeId;
-    IncidenceChanger *mChanger;
+    IncidenceChanger *mChanger = nullptr;
 
     int mIncidencesToDelete;
     int mIncidencesToAdd;
@@ -441,8 +440,8 @@ private Q_SLOTS:
         item.setMimeType(Event::eventMimeType());
         Event::Ptr incidence = Event::Ptr(new Event());
         incidence->setUid(QStringLiteral("test123uid"));
-        incidence->setDtStart(KDateTime(QDate(2006, 1, 8), QTime(12, 0, 0), KDateTime::UTC));
-        incidence->setDtEnd(KDateTime(QDate(2006, 1, 8), QTime(14, 0, 0), KDateTime::UTC));
+        incidence->setDtStart(QDateTime(QDate(2006, 1, 8), QTime(12, 0, 0), Qt::UTC));
+        incidence->setDtEnd(QDateTime(QDate(2006, 1, 8), QTime(14, 0, 0), Qt::UTC));
         incidence->setAllDay(false);
         incidence->setLocation(QStringLiteral("location"));
         incidence->setOrganizer(Person::Ptr(new Person(QString(), s_ourEmail)));
@@ -455,14 +454,14 @@ private Q_SLOTS:
 
         {
             Event::Ptr event = Event::Ptr(new Event(*incidence));
-            event->setDtStart(KDateTime(QDate(2006, 1, 8), QTime(13, 0, 0), KDateTime::UTC));
+            event->setDtStart(QDateTime(QDate(2006, 1, 8), QTime(13, 0, 0), Qt::UTC));
             QCOMPARE(event->dirtyFields().count(), 1);
             QTest::newRow("organizator:start Date") << item << event << true;
         }
 
         {
             Event::Ptr event = Event::Ptr(new Event(*incidence));
-            event->setDtEnd(KDateTime(QDate(2006, 1, 8), QTime(13, 0, 0), KDateTime::UTC));
+            event->setDtEnd(QDateTime(QDate(2006, 1, 8), QTime(13, 0, 0), Qt::UTC));
             QCOMPARE(event->dirtyFields().count(), 1);
             QTest::newRow("organizator:end Date") << item << event << true;
         }
@@ -493,8 +492,8 @@ private Q_SLOTS:
         item2.setMimeType(Event::eventMimeType());
         Event::Ptr incidence2 = Event::Ptr(new Event());
         incidence2->setUid(QStringLiteral("test123uid"));
-        incidence2->setDtStart(KDateTime(QDate(2006, 1, 8), QTime(12, 0, 0), KDateTime::UTC));
-        incidence2->setDtEnd(KDateTime(QDate(2006, 1, 8), QTime(14, 0, 0), KDateTime::UTC));
+        incidence2->setDtStart(QDateTime(QDate(2006, 1, 8), QTime(12, 0, 0), Qt::UTC));
+        incidence2->setDtEnd(QDateTime(QDate(2006, 1, 8), QTime(14, 0, 0), Qt::UTC));
         incidence2->setAllDay(false);
         incidence2->setLocation(QStringLiteral("location"));
         incidence2->setOrganizer(Person::Ptr(new Person(QStringLiteral("External organizator"), QStringLiteral("exorga@dev.nul"))));
@@ -507,13 +506,13 @@ private Q_SLOTS:
 
         {
             Event::Ptr event = Event::Ptr(new Event(*incidence2));
-            event->setDtStart(KDateTime(QDate(2006, 1, 8), QTime(13, 0, 0), KDateTime::UTC));
+            event->setDtStart(QDateTime(QDate(2006, 1, 8), QTime(13, 0, 0), Qt::UTC));
             QTest::newRow("attendee:start Date") << item2 << event << false;
         }
 
         {
             Event::Ptr event = Event::Ptr(new Event(*incidence2));
-            event->setDtEnd(KDateTime(QDate(2006, 1, 8), QTime(13, 0, 0), KDateTime::UTC));
+            event->setDtEnd(QDateTime(QDate(2006, 1, 8), QTime(13, 0, 0), Qt::UTC));
             QTest::newRow("attendee:end Date") << item2 << event << false;
         }
 
@@ -534,7 +533,6 @@ private Q_SLOTS:
             event->setSummary(QStringLiteral("summary"));
             QTest::newRow("attendee:summary") << item2 << event << false;
         }
-
     }
 
     void testModifyRescedule()
@@ -704,7 +702,7 @@ private Q_SLOTS:
         QTest::newRow("delete two - success ") << items << changeTypes << failureExpectedList
                                                << expectedResults << rights << false;
         //------------------------------------------------------------------------------------------
-        // Creation succeeds but deletion doesnt ( invalid item case )
+        // Creation succeeds but deletion doesn't ( invalid item case )
         items.clear();
         items << item() << Item(); // Invalid item on purpose
         changeTypes.clear();
@@ -736,7 +734,7 @@ private Q_SLOTS:
         QTest::newRow("try delete,create") << items << changeTypes << failureExpectedList
                                            << expectedResults << rights << false;
         //------------------------------------------------------------------------------------------
-        // Creation succeeds but deletion doesnt ( valid, inexistant item case )
+        // Creation succeeds but deletion doesn't ( valid, inexistant item case )
         items.clear();
         items << item() << Item(10101010);
         changeTypes.clear();
@@ -784,7 +782,7 @@ private Q_SLOTS:
         QTest::newRow("try delete(ACL),create") << items << changeTypes << failureExpectedList
                                                 << expectedResults << rights << false;
         //------------------------------------------------------------------------------------------
-        //Creation succeeds but deletion doesnt ( NO ACL case )
+        //Creation succeeds but deletion doesn't ( NO ACL case )
         items.clear();
         items << item() << createItem(mCollection);
         changeTypes.clear();
@@ -800,7 +798,7 @@ private Q_SLOTS:
         QTest::newRow("create,try delete(ACL)") << items << changeTypes << failureExpectedList
                                                 << expectedResults << rights << false;
         //------------------------------------------------------------------------------------------
-        // 1 successfull modification, 1 failed creation
+        // 1 successful modification, 1 failed creation
         changeTypes.clear();
         changeTypes << IncidenceChanger::ChangeTypeModify << IncidenceChanger::ChangeTypeCreate;
         items.clear();
@@ -816,7 +814,7 @@ private Q_SLOTS:
         QTest::newRow("modify,try create") << items << changeTypes << failureExpectedList
                                            << expectedResults << rights << false;
         //------------------------------------------------------------------------------------------
-        // 1 successfull modification, 1 failed creation
+        // 1 successful modification, 1 failed creation
         changeTypes.clear();
         changeTypes << IncidenceChanger::ChangeTypeModify << IncidenceChanger::ChangeTypeCreate;
         items.clear();
@@ -832,7 +830,7 @@ private Q_SLOTS:
         QTest::newRow("modify,try create v2") << items << changeTypes << failureExpectedList
                                               << expectedResults << rights << false;
         //------------------------------------------------------------------------------------------
-        // 1 failed creation, 1 successfull modification
+        // 1 failed creation, 1 successful modification
         changeTypes.clear();
         changeTypes << IncidenceChanger::ChangeTypeCreate << IncidenceChanger::ChangeTypeModify;
         items.clear();
@@ -848,7 +846,7 @@ private Q_SLOTS:
         QTest::newRow("try create,modify") << items << changeTypes << failureExpectedList
                                            << expectedResults << rights << false;
         //------------------------------------------------------------------------------------------
-        // 1 failed creation, 1 successfull modification
+        // 1 failed creation, 1 successful modification
         changeTypes.clear();
         changeTypes << IncidenceChanger::ChangeTypeCreate << IncidenceChanger::ChangeTypeModify;
         items.clear();
@@ -1057,8 +1055,8 @@ private Q_SLOTS:
     void testAdjustRecurrence_data()
     {
         QTest::addColumn<bool>("allDay");
-        QTest::addColumn<KDateTime>("dtStart");
-        QTest::addColumn<KDateTime>("dtEnd");
+        QTest::addColumn<QDateTime>("dtStart");
+        QTest::addColumn<QDateTime>("dtEnd");
         QTest::addColumn<int>("offsetToMove");
         QTest::addColumn<int>("frequency");
         QTest::addColumn<KCalCore::RecurrenceRule::PeriodType>("recurrenceType");
@@ -1071,8 +1069,8 @@ private Q_SLOTS:
         QTest::addColumn<QDate>("recurrenceEnd");
         QTest::addColumn<QDate>("expectedRecurrenceEnd");
 
-        const KDateTime dtStart = KDateTime(QDate::currentDate(), QTime(8, 0));
-        const KDateTime dtEnd = dtStart.addSecs(3600);
+        const QDateTime dtStart = QDateTime(QDate::currentDate(), QTime(8, 0));
+        const QDateTime dtEnd = dtStart.addSecs(3600);
         const int one_day = 3600 * 24;
         const int one_hour = 3600;
         QBitArray days(7);
@@ -1090,7 +1088,7 @@ private Q_SLOTS:
         days.setBit(dtStart.date().dayOfWeek() - 1);
         expectedDays.setBit(dtStart.addSecs(one_day).date().dayOfWeek() - 1);
 
-        QTest::newRow("weekly allday") << true << KDateTime(dtStart.date()) << KDateTime(dtEnd.date())
+        QTest::newRow("weekly allday") << true << QDateTime(dtStart.date()) << QDateTime(dtEnd.date())
                                        << one_day << 1 << KCalCore::RecurrenceRule::rWeekly
                                        << days << expectedDays << QDate() << QDate();
         //-------------------------------------------------------------------------
@@ -1124,8 +1122,8 @@ private Q_SLOTS:
     void testAdjustRecurrence()
     {
         QFETCH(bool, allDay);
-        QFETCH(KDateTime, dtStart);
-        QFETCH(KDateTime, dtEnd);
+        QFETCH(QDateTime, dtStart);
+        QFETCH(QDateTime, dtEnd);
         QFETCH(int, offsetToMove);
         QFETCH(int, frequency);
         QFETCH(KCalCore::RecurrenceRule::PeriodType, recurrenceType);
