@@ -25,7 +25,8 @@
 #include "akonadicalendar_debug.h"
 using namespace Akonadi;
 
-ITIPHandler::Private::Private(ITIPHandlerComponentFactory *factory, ITIPHandler *qq) : m_calendarLoadError(false)
+ITIPHandler::Private::Private(ITIPHandlerComponentFactory *factory, ITIPHandler *qq)
+    : m_calendarLoadError(false)
     , m_factory(factory ? factory : new ITIPHandlerComponentFactory(this))
     , m_scheduler(new MailScheduler(m_factory, qq))
     , m_method(KCalCore::iTIPNoMethod)
@@ -203,10 +204,10 @@ void ITIPHandler::Private::finishPublishInformation(Akonadi::MailScheduler::Resu
     }
 }
 
-void ITIPHandler::Private::finishSendAsICalendar(Akonadi::MailScheduler::Result result,
+void ITIPHandler::Private::finishSendAsICalendar(Akonadi::MailClient::Result result,
         const QString &errorMessage)
 {
-    if (result == Scheduler::ResultSuccess) {
+    if (result == MailClient::ResultSuccess) {
         if (m_parentWidget) {
             KMessageBox::information(m_parentWidget,
                                      i18n("The item information was successfully sent."),
